'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.fetchRouteData = exports.fetchSuccess = exports.fetchRequest = exports.fetchFailure = undefined;

var _typeof2 = require('babel-runtime/helpers/typeof');

var _typeof3 = _interopRequireDefault(_typeof2);

var _ActionTypes = require('./ActionTypes');

var _ActionTypes2 = _interopRequireDefault(_ActionTypes);

var _formatError = require('./formatError');

var _formatError2 = _interopRequireDefault(_formatError);

var _isError = require('./isError');

var _isError2 = _interopRequireDefault(_isError);

var _uniqueId = require('./uniqueId');

var _uniqueId2 = _interopRequireDefault(_uniqueId);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var fetchFailure = exports.fetchFailure = function fetchFailure(error, fetchId, location) {
  return {
    type: _ActionTypes2.default.FETCH_FAILURE, error: error, fetchId: fetchId, location: location
  };
};

var fetchRequest = exports.fetchRequest = function fetchRequest(fetchId, location) {
  return {
    type: _ActionTypes2.default.FETCH_REQUEST, fetchId: fetchId, location: location
  };
};

var fetchSuccess = exports.fetchSuccess = function fetchSuccess(fetchId, location) {
  return {
    type: _ActionTypes2.default.FETCH_SUCCESS, fetchId: fetchId, location: location
  };
};

/**
 * Fetch data required to render components matched to the current location.
 * @param {RouterState} props An object representing the current state of the router.
 * @return {Promise} A promise that is settled after data requirements for all
 * matched route components is either complete or fails.
*/
var fetchRouteData = exports.fetchRouteData = function fetchRouteData(props) {
  return function (dispatch, getState) {
    var location = props.location,
        components = props.components;

    var fetchId = (0, _uniqueId2.default)();

    dispatch(fetchRequest(fetchId, location));

    var promises = components
    // Grab route components from the current router state.
    .reduce(function (accumulator, component) {
      // A component may be a plain object when named components are used.
      if ((typeof component === 'undefined' ? 'undefined' : (0, _typeof3.default)(component)) === 'object') {
        Object.keys(component).forEach(function (key) {
          accumulator.push(component[key]);
        });
      } else {
        accumulator.push(component);
      }

      return accumulator;
    }, [])
    // Filter falsy components
    .filter(function (component) {
      return component;
    })
    // Filter components that haven't been decorated
    .filter(function (component) {
      return component.fetchAsyncState;
    })
    // Fetch data requirements and store promises
    .map(function (component) {
      return component.fetchAsyncState(dispatch, getState, props);
    });

    return Promise.all(promises).then(function () {
      dispatch(fetchSuccess(fetchId, location));
    }, function (error) {
      // Ideally, developers catch and handle runtime errors that occur in async
      // actions dispatched to fulfill data requirements, however, it's not a
      // great developer experience when you have to debug an error that
      // dissapears into the ether. As a result, we will reformat native errors
      // into JSON format so that it can be stored in Redux and rethrow the error
      // so it's printed in the browser developer tools.
      dispatch(fetchFailure((0, _formatError2.default)(error), fetchId, location));
      if ((0, _isError2.default)(error)) throw error;
    });
  };
};