'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

exports.default = function () {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultState;
  var action = arguments[1];

  switch (action.type) {
    case _ActionTypes2.default.FETCH_FAILURE:
      return failureReducer(state, action);
    case _ActionTypes2.default.FETCH_REQUEST:
      return requestReducer(state, action);
    case _ActionTypes2.default.FETCH_SUCCESS:
      return successReducer(state, action);
    default:
      return state;
  }
};

var _ActionTypes = require('./ActionTypes');

var _ActionTypes2 = _interopRequireDefault(_ActionTypes);

var _ReadyState = require('./ReadyState');

var _ReadyState2 = _interopRequireDefault(_ReadyState);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var defaultState = {
  readyState: _ReadyState2.default.PENDING
};

var isSameFetchId = function isSameFetchId(state, action) {
  return state.fetchId === action.fetchId;
};

var requestReducer = function requestReducer(state, action) {
  return (0, _extends3.default)({}, state, {
    fetchId: action.fetchId,
    location: action.location,
    readyState: _ReadyState2.default.LOADING
  });
};

var failureReducer = function failureReducer(state, action) {
  if (!isSameFetchId(state, action)) return state;
  return (0, _extends3.default)({}, state, {
    error: action.error,
    fetchId: action.fetchId,
    location: action.location,
    readyState: _ReadyState2.default.FAILURE
  });
};

var successReducer = function successReducer(state, action) {
  if (!isSameFetchId(state, action)) return state;
  return (0, _extends3.default)({}, state, {
    fetchId: action.fetchId,
    location: action.location,
    readyState: _ReadyState2.default.SUCCESS
  });
};